API
===

anfema_django_testutils.testcases
---------------------------------

.. automodule:: anfema_django_testutils.testcases
   :members: PreconditionError, PreconditionContext, precondition, repeat

.. autoclass:: anfema_django_testutils.testcases.SimpleTestCase
   :members:
   :inherited-members:

.. autoclass:: anfema_django_testutils.testcases.TransactionTestCase
   :members:

.. autoclass:: anfema_django_testutils.testcases.TestCase
   :members:


anfema_django_testutils.tags
----------------------------

.. automodule:: anfema_django_testutils.tags
   :members:
